@@ -472,6 +472,9 @@ class CfnFileSystem(
         jsii_type="@aws-cdk/aws-fsx.CfnFileSystem.LustreConfigurationProperty",
         jsii_struct_bases=[],
         name_mapping={
+            "automatic_backup_retention_days": "automaticBackupRetentionDays",
+            "copy_tags_to_backups": "copyTagsToBackups",
+            "daily_automatic_backup_start_time": "dailyAutomaticBackupStartTime",
             "deployment_type": "deploymentType",
             "export_path": "exportPath",
             "imported_file_chunk_size": "importedFileChunkSize",
@@ -484,6 +487,11 @@ class CfnFileSystem(
         def __init__(
             self,
             *,
+            automatic_backup_retention_days: typing.Optional[jsii.Number] = None,
+            copy_tags_to_backups: typing.Optional[
+                typing.Union[bool, aws_cdk.core.IResolvable]
+            ] = None,
+            daily_automatic_backup_start_time: typing.Optional[str] = None,
             deployment_type: typing.Optional[str] = None,
             export_path: typing.Optional[str] = None,
             imported_file_chunk_size: typing.Optional[jsii.Number] = None,
@@ -492,6 +500,9 @@ class CfnFileSystem(
             weekly_maintenance_start_time: typing.Optional[str] = None,
         ) -> None:
             """
+            :param automatic_backup_retention_days: ``CfnFileSystem.LustreConfigurationProperty.AutomaticBackupRetentionDays``.
+            :param copy_tags_to_backups: ``CfnFileSystem.LustreConfigurationProperty.CopyTagsToBackups``.
+            :param daily_automatic_backup_start_time: ``CfnFileSystem.LustreConfigurationProperty.DailyAutomaticBackupStartTime``.
             :param deployment_type: ``CfnFileSystem.LustreConfigurationProperty.DeploymentType``.
             :param export_path: ``CfnFileSystem.LustreConfigurationProperty.ExportPath``.
             :param imported_file_chunk_size: ``CfnFileSystem.LustreConfigurationProperty.ImportedFileChunkSize``.
@@ -503,6 +514,16 @@ class CfnFileSystem(
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-lustreconfiguration.html
             """
             self._values = {}
+            if automatic_backup_retention_days is not None:
+                self._values[
+                    "automatic_backup_retention_days"
+                ] = automatic_backup_retention_days
+            if copy_tags_to_backups is not None:
+                self._values["copy_tags_to_backups"] = copy_tags_to_backups
+            if daily_automatic_backup_start_time is not None:
+                self._values[
+                    "daily_automatic_backup_start_time"
+                ] = daily_automatic_backup_start_time
             if deployment_type is not None:
                 self._values["deployment_type"] = deployment_type
             if export_path is not None:
@@ -520,6 +541,35 @@ class CfnFileSystem(
                     "weekly_maintenance_start_time"
                 ] = weekly_maintenance_start_time
 
+        @builtins.property
+        def automatic_backup_retention_days(self) -> typing.Optional[jsii.Number]:
+            """``CfnFileSystem.LustreConfigurationProperty.AutomaticBackupRetentionDays``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-lustreconfiguration.html#cfn-fsx-filesystem-lustreconfiguration-automaticbackupretentiondays
+            """
+            return self._values.get("automatic_backup_retention_days")
+
+        @builtins.property
+        def copy_tags_to_backups(
+            self,
+        ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+            """``CfnFileSystem.LustreConfigurationProperty.CopyTagsToBackups``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-lustreconfiguration.html#cfn-fsx-filesystem-lustreconfiguration-copytagstobackups
+            """
+            return self._values.get("copy_tags_to_backups")
+
+        @builtins.property
+        def daily_automatic_backup_start_time(self) -> typing.Optional[str]:
+            """``CfnFileSystem.LustreConfigurationProperty.DailyAutomaticBackupStartTime``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-lustreconfiguration.html#cfn-fsx-filesystem-lustreconfiguration-dailyautomaticbackupstarttime
+            """
+            return self._values.get("daily_automatic_backup_start_time")
+
         @builtins.property
         def deployment_type(self) -> typing.Optional[str]:
             """``CfnFileSystem.LustreConfigurationProperty.DeploymentType``.
